%def_without 	debug
%def_with 	svg
%def_without 	libxul

%if_with debug
%set_strip_method none
%endif # debug

Summary:        Mozilla's Calendar Application
Name:           %sunbird_name
Version:        %sunbird_version
Release:       	%sunbird_release
License:        MPL/GPL/LGPL
Group:          Office
Url:		http://www.mozilla.org/projects/calendar/sunbird/

Source0:	sunbird-source.tar
Source1:	sunbird-icons.tar
Source2:	sunbird.desktop

Patch1:		sunbird-alt-extensions-dir.patch
Patch2:		sunbird-alt-prefs-tuning.patch
Patch3:		mozilla-alt-default-x11-path.patch
Patch4:		sunbird-alt-allow-x86_64-host-build.patch

Patch5:		firefox-1.5.0.1-alt-asm-directive.patch
Patch6:		mozilla-firefox-1.0-lib64.patch
Patch7:		xulrunner-symbols-fix.patch
Patch8:		thunderbird-alt-with-system-mozldap.patch
Patch9:		mozilla-embedding-linker-fix.patch
Patch10:	mozilla-libs-fix.patch

BuildRequires: doxygen gcc-c++ imake libgtk+2-devel libIDL-devel libjpeg-devel 
BuildRequires: libnss-devel-static libXinerama-devel libXp-devel libXt-devel libXft-devel
BuildRequires: makedepend nss-utils unzip xorg-cf-files zip chrpath

BuildRequires(pre): rpm-build-sunbird

BuildRequires: autoconf_2.13
%set_autoconf_version 2.13

%description
The Sunbird Project is a redesign of the Mozilla Calendar component.
The goal is to produce a cross-platform stand-alone calendar
application based on Mozilla's XUL user interface language. At the
moment, the Sunbird name is a project name. It is not official and may
change in the future.

The intended user is someone who uses Mozilla Firefox and Mozilla
Thunderbird and wants a calendar application based on Mozilla.

%prep
%setup -q -n %name-%version -c
%setup -q -n %name-%version/mozilla -T -D -a1

%patch1  -p1 -b .fix1
%patch2  -p1 -b .fix2
%patch3  -p1 -b .fix3
%patch4  -p1 -b .fix4
%patch5  -p1 -b .fix5
%patch6  -p1 -b .fix6
%patch7  -p1 -b .fix7
%patch8  -p1 -b .fix8
%patch9  -p1 -b .fix9
%patch10 -p1 -b .fix10

%build
%add_optflags %optflags_shared
%add_findprov_lib_path %sunbird_prefix

%__subst 's|AC_CONFIG_AUX_DIR(\${srcdir}/build/autoconf)|AC_CONFIG_AUX_DIR(build/autoconf)|' configure.in
%__autoconf

# Add fake RPATH
rpath="/$(printf %%s '%sunbird_prefix' |tr '[:print:]' '_')"
export LDFLAGS="$LDFLAGS -Wl,-rpath,$rpath"
export LIBIDL_CONFIG=/usr/bin/libIDL-config-2

%configure \
	--prefix=%_prefix \
	--disable-activex \
	--disable-activex-scripting \
	--disable-tests \
	--disable-oji \
	--disable-installer \
	--disable-updater \
	--disable-tests \
	--disable-freetype2 \
	--disable-javaxpcom \
	--disable-elf-dynstr-gc \
	--enable-xft \
	--enable-crypto \
	--enable-application=calendar \
	--enable-optimize="-O2" \
	--enable-default-toolkit=gtk2 \
	\
%if_with debug
	--disable-strip \
	--enable-debug \
	--enable-debug-modules \
	--enable-logrefcnt \
	--enable-debugger-info-modules \
	--enable-detect-webshell-leaks \
%else
	--enable-strip \
	--disable-debug \
%endif # debug
	\
%if_with svg
	--enable-svg \
  	--enable-svg-renderer-cairo \
%endif # svg
	\
%if_with libxul
	--enable-libxul \
%endif # libxul
	\
	--enable-canvas \
	--enable-system-cairo \
	--with-system-jpeg \
	--with-system-png \
	--with-system-zlib \
	--with-system-nspr \
	--with-system-nss \
	--with-system-ldap \
	--with-pthreads \
	#

%make_build

%install
%__mkdir_p \
	%buildroot/%sunbird_updatesdir/0 \
	%buildroot/%sunbird_arch_extensionsdir \
	%buildroot/%sunbird_noarch_extensionsdir \
	%buildroot/%sunbird_prefix/dictionaries \
	#

# Hack? hack... HACK!!!
for i in 1 2; do
	%make_install install \
		DESTDIR=%buildroot \
		idldir=%_datadir/idl/%name \
		includedir=%_includedir/%name \
		mozappdir=%sunbird_prefix \
		&& break ||
	%make -C xpfe/components libs
done

# Install icons
install -D icons/%name-16.png  %buildroot/%_miconsdir/%name.png
install -D icons/%name-32.png  %buildroot/%_niconsdir/%name.png
install -D icons/%name-48.png  %buildroot/%_liconsdir/%name.png
install -D icons/%name-128.png %buildroot/%_iconsdir/hicolor/128x128/apps/%name.png

# Install desktop file
install -m644 -D %SOURCE2 %buildroot/%_desktopdir/%name.desktop

for d in %buildroot/%sunbird_arch_extensionsdir/*; do
	touch "$d"/chrome.manifest
done

sed -i -e 's|^moz_libdir=.*|moz_libdir=%sunbird_prefix|' "%buildroot/%sunbird_exec"

%__rm -rf -- \
    %buildroot/%_bindir/%name-config \
    %buildroot/%sunbird_prefix/TestGtkEmbed \
    \
    %buildroot/%_datadir/idl \
    %buildroot/%_libdir/pkgconfig \
    %buildroot/%_includedir \
    %buildroot/%sunbird_prefix/regxpcom \
    %buildroot/%sunbird_prefix/xpcshell \
    %buildroot/%sunbird_prefix/xpicleanup \
    %buildroot/%sunbird_prefix/xpidl \
    %buildroot/%sunbird_prefix/xpt_dump \
    %buildroot/%sunbird_prefix/xpt_link \
    #

# Add real RPATH
rpath="/$(printf %%s '%sunbird_prefix' |tr '[:print:]' '_')"
find "%buildroot/%sunbird_prefix" -type f | 
while read f; do
	%__file "$f" | grep -qs ELF || continue
	if chrpath -l "$f" | fgrep -qs "RPATH=$rpath"; then
		chrpath -r "%sunbird_prefix" "$f"
	fi
done

%pre
if [ -L "%_libdir/%name" -a -d "%_libdir/%name-0.7.0" ]; then
	rm -f -- "%_libdir/%name"
	rm -rf -- "%_libdir/%name-0.7.0"
fi

%preun
if [ "$1" = "0" ]; then
    [ ! -d "%sunbird_noarch_extensionsdir" ] || %__rm -rf "%sunbird_noarch_extensionsdir"
    [ ! -d "%sunbird_arch_extensionsdir" ] || %__rm -rf "%sunbird_arch_extensionsdir"
    [ ! -d "%sunbird_componentsdir" ] || %__rm -rf "%sunbird_componentsdir"
    [ ! -d "%sunbird_updatesdir" ] || %__rm -rf "%sunbird_updatesdir"
fi

%post
%update_menus

%postun
%clean_menus

%files
%sunbird_exec
%sunbird_prefix
%sunbird_datadir
%defattr(0644,root,root,0755)
%_desktopdir/%name.desktop
%_miconsdir/%name.png
%_niconsdir/%name.png
%_liconsdir/%name.png
%_iconsdir/hicolor/128x128/apps/%name.png
%doc LEGAL LICENSE

%changelog
* Tue Nov 13 2007 Alexey Gladkov <legion@altlinux.ru> 0.7.0-alt2
- Bugfix build.
- Fix startup script.

* Sun Oct 14 2007 Alexey Gladkov <legion@altlinux.ru> 0.7.0-alt1
- New version (0.7).

* Fri Dec 08 2006 Damir Shayhutdinov <damir@altlinux.ru> 0.3-alt1
- Initial build for ALT Linux.
